"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = AppBar;
exports.styles = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _clsx3 = _interopRequireDefault(require("clsx"));

var _core = require("@material-ui/core");

var _styles = require("@material-ui/core/styles");

var _amp = require("next/amp");

var _PWAContext = _interopRequireDefault(require("./PWAContext"));

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { (0, _defineProperty2["default"])(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

var styles = function styles(theme) {
  return {
    root: {
      height: 64,
      boxSizing: 'content-box',
      position: 'relative',
      zIndex: theme.zIndex.modal + 10
    },
    withAmp: {
      zIndex: theme.zIndex.amp.modal + 1
    },
    offline: {
      textAlign: 'center',
      backgroundColor: '#f34c4c',
      color: 'white'
    },
    toolBar: {
      height: '64px',
      maxWidth: theme.maxWidth,
      flex: 1
    },
    wrap: {
      borderBottom: "1px solid ".concat(theme.palette.divider),
      position: 'absolute',
      top: 0,
      left: 0,
      right: 0,
      backgroundColor: theme.palette.background.paper,
      zIndex: theme.zIndex.modal + 10,
      display: 'flex',
      justifyContent: 'center'
    },
    unstuck: {
      transform: 'translateY(-100%)'
    },
    animate: {
      transition: 'transform .15s ease-in'
    },
    hidden: {
      position: 'fixed',
      zIndex: theme.zIndex.modal + 10,
      boxShadow: theme.shadows[2],
      top: 0,
      left: 0,
      right: 0
    },
    fixed: {
      position: 'fixed'
    },
    link: {
      textDecoration: 'none'
    }
  };
};

exports.styles = styles;
var useStyles = (0, _styles.makeStyles)(styles, {
  name: 'RSFAppBar'
});

function AppBar(_ref) {
  var _clsx, _clsx2;

  var classes = _ref.classes,
      children = _ref.children,
      fixed = _ref.fixed,
      offlineWarning = _ref.offlineWarning;
  classes = useStyles({
    classes: classes
  });

  var _useState = (0, _react.useState)({
    stuck: false,
    hidden: false,
    animate: false
  }),
      _useState2 = (0, _slicedToArray2["default"])(_useState, 2),
      state = _useState2[0],
      applyState = _useState2[1];

  var stuck = state.stuck,
      hidden = state.hidden,
      animate = state.animate;

  var setState = function setState(newState) {
    return applyState(_objectSpread({}, state, {}, newState));
  };

  var lastScrollY = (0, _react.useRef)();
  var unstickAt = (0, _react.useRef)();
  var stickAt = (0, _react.useRef)();

  var _useContext = (0, _react.useContext)(_PWAContext["default"]),
      offline = _useContext.offline;

  var items = _react["default"].Children.toArray(children);

  var onScroll = function onScroll() {
    var height = 64,
        _window = window,
        scrollY = _window.scrollY,
        unstickBufferZone = 30;

    if (scrollY === 0) {
      setState({
        hidden: false,
        stuck: false,
        animate: false
      });
    } else if (scrollY > height && !hidden) {
      setState({
        hidden: true
      });
    }

    if (scrollY < stickAt.current && !stuck) {
      stickAt.current = null;
      unstickAt.current = scrollY + unstickBufferZone;
      setState({
        stuck: true
      });
    } else if (scrollY > unstickAt.current && stuck) {
      unstickAt.current = null;
      stickAt.current = scrollY - unstickBufferZone;
      setState({
        stuck: false
      });
    }

    if (lastScrollY.current > scrollY && stuck) {
      unstickAt.current = scrollY + unstickBufferZone;
    }

    if (lastScrollY.current < scrollY && !stuck) {
      stickAt.current = scrollY - unstickBufferZone;
    }

    lastScrollY.current = scrollY;
  };

  (0, _react.useEffect)(function () {
    if (!fixed) {
      window.addEventListener('scroll', onScroll, {
        passive: true
      });
      return function () {
        return window.removeEventListener('scroll', onScroll, {
          passive: true
        });
      };
    }
  }, [state]);
  (0, _react.useEffect)(function () {
    if (hidden && !animate) {
      setTimeout(function () {
        return setState({
          animate: true
        });
      }, 100);
    }
  }, [hidden]);
  return _react["default"].createElement("div", null, offline && _react["default"].createElement("div", {
    className: classes.offline
  }, offlineWarning), _react["default"].createElement("div", {
    className: (0, _clsx3["default"])((_clsx = {}, (0, _defineProperty2["default"])(_clsx, classes.root, true), (0, _defineProperty2["default"])(_clsx, classes.withAmp, (0, _amp.useAmp)()), _clsx))
  }, _react["default"].createElement("div", {
    className: (0, _clsx3["default"])((_clsx2 = {}, (0, _defineProperty2["default"])(_clsx2, classes.wrap, true), (0, _defineProperty2["default"])(_clsx2, classes.fixed, fixed), (0, _defineProperty2["default"])(_clsx2, classes.hidden, hidden), (0, _defineProperty2["default"])(_clsx2, classes.unstuck, hidden && !stuck), (0, _defineProperty2["default"])(_clsx2, classes.animate, animate && window.scrollY > 0), _clsx2))
  }, _react["default"].createElement(_core.Toolbar, {
    disableGutters: true,
    classes: {
      root: classes.toolBar
    }
  }, items))));
}

AppBar.propTypes = {
  /**
   * CSS classes
   */
  classes: _propTypes["default"].object,

  /**
   * Fixed AppBar
   */
  fixed: _propTypes["default"].bool,

  /**
   * String or Element to render within the offline warning container at the top of the app
   */
  offlineWarning: _propTypes["default"].oneOfType([_propTypes["default"].string, _propTypes["default"].element])
};
AppBar.defaultProps = {
  offlineWarning: 'Your device lost its internet connection.',
  fixed: false
};
//# sourceMappingURL=AppBar.js.map