"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = ExpandableSection;
exports.styles = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _clsx5 = _interopRequireDefault(require("clsx"));

var _core = require("@material-ui/core");

var _icons = require("@material-ui/icons");

var _styles = require("@material-ui/core/styles");

var _useStateFromProp3 = _interopRequireDefault(require("./hooks/useStateFromProp"));

var _withDefaultHandler = _interopRequireDefault(require("./utils/withDefaultHandler"));

var styles = function styles(theme) {
  return {
    root: {
      boxShadow: 'none',
      borderBottom: "1px solid ".concat(theme.palette.divider),
      background: 'transparent',
      '&::before': {
        display: 'none'
      },
      '& > *:first-child': {
        padding: '0',
        minHeight: '0'
      }
    },
    margins: {
      padding: "0 ".concat(theme.spacing(2), "px")
    },
    caption: {
      transition: 'opacity .2s linear'
    },
    expandedCaption: {
      opacity: 0
    },
    largeTitle: {
      fontSize: '18px',
      fontWeight: 'bold',
      color: '#444'
    },
    details: {
      padding: theme.spacing(0, 0, 2, 0),
      display: 'flex',
      flexDirection: 'column'
    },
    summary: {
      '&:first-child': {
        padding: theme.spacing(1, 0)
      }
    },
    summaryContent: {
      display: 'flex',
      justifyContent: 'space-between',
      alignItems: 'center',
      margin: 0,
      '[aria-expanded=true] > &': {
        margin: '0 !important'
      }
    },
    summaryExpanded: {},
    expandIconExpanded: {},
    withCollapseIcon: {
      transform: 'rotate(0deg) !important'
    },
    summaryIconWrap: {
      right: 0,
      padding: theme.spacing(0, 1)
    },
    expandedPanel: {
      '&$root': {
        margin: 0
      }
    },
    title: {},
    expandIcon: {},
    collapseIcon: {}
  };
};

exports.styles = styles;
var useStyles = (0, _styles.makeStyles)(styles, {
  name: 'RSFExpandableSection'
});
/**
 * An expandable info section.  Example:
 *
 * ```js
 *  <ExpandableSection title="Help" caption="Click here for more info">
 *    <Typography>This is a help section</Typography>
 *  </ExpandableSection>
 * ```
 */

function ExpandableSection(props) {
  var _clsx3, _clsx4;

  var classes = props.classes,
      _props$children = props.children,
      children = _props$children === void 0 ? [] : _props$children,
      title = props.title,
      caption = props.caption,
      expanded = props.expanded,
      defaultExpanded = props.defaultExpanded,
      ExpandIcon = props.ExpandIcon,
      CollapseIcon = props.CollapseIcon,
      margins = props.margins,
      onChange = props.onChange,
      others = (0, _objectWithoutProperties2["default"])(props, ["classes", "children", "title", "caption", "expanded", "defaultExpanded", "ExpandIcon", "CollapseIcon", "margins", "onChange"]);
  classes = useStyles({
    classes: classes
  });

  var _useStateFromProp = (0, _useStateFromProp3["default"])(expanded || defaultExpanded || false),
      _useStateFromProp2 = (0, _slicedToArray2["default"])(_useStateFromProp, 2),
      expandedState = _useStateFromProp2[0],
      setExpandedState = _useStateFromProp2[1];
  /**
   * Gets the classes for the ExpansionPanelSummary
   * Here we add a class to remove the rotate transform if we're using a
   * separate icon for the collapse state.
   */


  function getSummaryClasses() {
    var _clsx, _clsx2;

    var result = {
      root: (0, _clsx5["default"])((_clsx = {}, (0, _defineProperty2["default"])(_clsx, classes.summary, true), (0, _defineProperty2["default"])(_clsx, classes.summaryExpanded, expandedState), _clsx)),
      content: classes.summaryContent,
      expandIcon: (0, _clsx5["default"])((_clsx2 = {}, (0, _defineProperty2["default"])(_clsx2, classes.summaryIconWrap, true), (0, _defineProperty2["default"])(_clsx2, classes.expandIconExpanded, expandedState), _clsx2))
    };

    if (CollapseIcon !== ExpandIcon) {
      result.expandIcon = classes.withCollapseIcon;
    }

    return result;
  }

  var handleChange = (0, _withDefaultHandler["default"])(onChange, function (e, expanded) {
    if (props.expanded == null) {
      setExpandedState(expanded);
    }
  });
  return _react["default"].createElement(_core.ExpansionPanel, (0, _extends2["default"])({
    classes: {
      root: (0, _clsx5["default"])((_clsx3 = {}, (0, _defineProperty2["default"])(_clsx3, classes.root, true), (0, _defineProperty2["default"])(_clsx3, classes.margins, margins), _clsx3)),
      expanded: classes.expandedPanel
    },
    expanded: expandedState,
    defaultExpanded: defaultExpanded
  }, others, {
    onChange: handleChange
  }), _react["default"].createElement(_core.ExpansionPanelSummary, {
    expandIcon: expandedState ? _react["default"].createElement(CollapseIcon, {
      className: classes.collapseIcon
    }) : _react["default"].createElement(ExpandIcon, {
      className: classes.expandIcon
    }),
    classes: getSummaryClasses()
  }, _react["default"].createElement(_core.Typography, {
    variant: "subtitle1",
    className: classes.title
  }, title), caption && _react["default"].createElement(_core.Typography, {
    variant: "caption",
    className: (0, _clsx5["default"])((_clsx4 = {}, (0, _defineProperty2["default"])(_clsx4, classes.caption, true), (0, _defineProperty2["default"])(_clsx4, classes.expandedCaption, expandedState), _clsx4))
  }, caption)), _react["default"].createElement(_core.ExpansionPanelDetails, {
    classes: {
      root: classes.details
    }
  }, children));
}

ExpandableSection.propTypes = {
  /**
   * The title for the header of the expandable section
   */
  title: _propTypes["default"].oneOfType([_propTypes["default"].string, _propTypes["default"].element]),

  /**
   * Text to display to the right of the heading
   */
  caption: _propTypes["default"].oneOfType([_propTypes["default"].string, _propTypes["default"].element]),

  /**
   * The icon to use for collapsed groups
   */
  ExpandIcon: _propTypes["default"].object,

  /**
   * The icon to use for expanded groups
   */
  CollapseIcon: _propTypes["default"].object,

  /**
   * Set to false to remove the default left and right margins. Defaults to `true`.
   */
  margins: _propTypes["default"].bool,

  /**
   * Controls the expanded state.  Defaults to false
   */
  expanded: _propTypes["default"].bool,

  /**
   * Defaults the panel to being expanded, without controlling the state.  Defaults to false
   */
  defaultExpanded: _propTypes["default"].bool
};
ExpandableSection.defaultProps = {
  margins: true,
  ExpandIcon: _icons.ExpandMore,
  CollapseIcon: _icons.ExpandMore
};
//# sourceMappingURL=ExpandableSection.js.map