"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard");

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = LoadMask;
exports.styles = void 0;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _react = _interopRequireWildcard(require("react"));

var _clsx2 = _interopRequireDefault(require("clsx"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _styles = require("@material-ui/core/styles");

var _core = require("@material-ui/core");

var styles = function styles(theme) {
  return {
    root: {
      position: 'absolute',
      top: 0,
      left: 0,
      height: '100%',
      width: '100%',
      display: 'none',
      justifyContent: 'center',
      alignItems: 'center',
      background: theme.palette.background["default"],
      zIndex: 1
    },
    fullscreen: {
      height: "calc(100vh - ".concat(theme.loadMaskOffsetTop, "px)"),
      bottom: 'initial',
      zIndex: theme.zIndex.modal - 20,
      'body.moov-amp &': {
        position: 'fixed',
        marginTop: 0,
        opacity: 0.8
      }
    },
    transparent: {
      backgroundColor: 'rgba(255,255,255,0.5)'
    },
    alignTop: {
      alignItems: 'flex-start',
      paddingTop: '200px'
    },
    show: {
      display: 'flex'
    }
  };
};

exports.styles = styles;
var useStyles = (0, _styles.makeStyles)(styles, {
  name: 'RSFLoadMask'
});
/**
 * The load mask displays when fetching data from the server.
 */

function LoadMask(_ref) {
  var _clsx;

  var classes = _ref.classes,
      show = _ref.show,
      style = _ref.style,
      className = _ref.className,
      children = _ref.children,
      fullscreen = _ref.fullscreen,
      transparent = _ref.transparent,
      align = _ref.align;
  classes = useStyles({
    classes: classes
  });
  (0, _react.useEffect)(function () {
    if (fullscreen) {
      document.body.style.overflow = show ? 'hidden' : 'visible';
    }
  }, [show, fullscreen]);
  (0, _react.useEffect)(function () {
    return function () {
      if (fullscreen) {
        document.body.style.overflow = 'visible';
      }
    };
  });
  return _react["default"].createElement("div", {
    style: style,
    className: (0, _clsx2["default"])((_clsx = {}, (0, _defineProperty2["default"])(_clsx, classes.root, true), (0, _defineProperty2["default"])(_clsx, className, className != null), (0, _defineProperty2["default"])(_clsx, classes.show, show !== false), (0, _defineProperty2["default"])(_clsx, classes.fullscreen, fullscreen), (0, _defineProperty2["default"])(_clsx, classes.transparent, transparent), (0, _defineProperty2["default"])(_clsx, classes.alignTop, align === 'top'), _clsx))
  }, children || _react["default"].createElement(_core.CircularProgress, {
    className: classes.progress,
    color: "secondary"
  }));
}

LoadMask.propTypes = {
  /**
   * Set to true to display the load mask, otherwise it will be hidden.
   * Defaults to false.
   */
  show: _propTypes["default"].bool,

  /**
   * Set to true to toggle the overflow style on the body when showing.
   * Defaults to false
   */
  fullscreen: _propTypes["default"].bool,

  /**
   * Set to true to show partially background through the load mask
   */
  transparent: _propTypes["default"].bool,

  /**
   * Set to top to show the spinner near the top. Defaults to 'center'
   */
  align: _propTypes["default"].oneOf(['center', 'top'])
};
LoadMask.defaultProps = {
  show: null,
  fullscreen: false,
  transparent: false,
  align: 'center'
};
//# sourceMappingURL=LoadMask.js.map